@@ -5,7 +5,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2020	PgPool Global Development Group
+ * Copyright (c) 2003-2017	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -299,7 +299,6 @@ int pool_do_auth(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *cp)
 						ereport(NOTICE,
 							(errmsg("notice from backend"),
 								errdetail("BACKEND NOTICE: \"%s\"",message)));
-						pfree(message);
 					}
 					/* process notice message */
 					if (SimpleForwardToFrontend(kind, frontend, cp))
@@ -327,8 +326,6 @@ int pool_do_auth(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *cp)
 						(errmsg("authentication failed, backend node replied with an error"),
 							errdetail("SERVER ERROR:\"%s\"",message?message:"could not extract backend message")));
 
-					if (message)
-						pfree(message);
 					break;
 
 				default:
@@ -411,6 +408,8 @@ int pool_do_auth(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *cp)
 			strlcpy(cp->info[i].database, sp->database, sizeof(cp->info[i].database));
 			strlcpy(cp->info[i].user, sp->user, sizeof(cp->info[i].user));
 			cp->info[i].counter = 1;
+			CONNECTION(cp, i)->con_info = &cp->info[i];
+			cp->info[i].swallow_termination = 0;
 		}
 	}
 
@@ -605,15 +604,13 @@ static int do_clear_text_password(POOL_CONNECTION *backend, POOL_CONNECTION *fro
 	{
 		if(response == 'E') /* Backend has thrown an error instead */
 		{
-			char* message = NULL;
+			char* message;
 			if (pool_extract_error_message(false, backend, protoMajor, false, &message) == 1)
 			{
 				ereport(ERROR,
 					(errmsg("clear text password authentication failed"),
 					 errdetail("%s",message?message:"backend throws authentication error")));
 			}
-			if (message)
-				pfree(message);
 		}
         ereport(ERROR,
             (errmsg("clear text password authentication failed"),
@@ -633,7 +630,7 @@ static int do_clear_text_password(POOL_CONNECTION *backend, POOL_CONNECTION *fro
 	pool_read(backend, &kind, sizeof(kind));
 
 	/* if authenticated, save info */
-	if (kind == 0)
+	if (!reauth && kind == 0)
 	{
 		if (IS_MASTER_NODE_ID(backend->db_node_id))
 		{
@@ -754,15 +751,13 @@ static int do_crypt(POOL_CONNECTION *backend, POOL_CONNECTION *frontend, int rea
 	{
 		if(response == 'E') /* Backend has thrown an error instead */
 		{
-			char* message = NULL;
+			char* message;
 			if (pool_extract_error_message(false, backend, protoMajor, false, &message) == 1)
 			{
 				ereport(ERROR,
 						(errmsg("crypt authentication failed"),
 						 errdetail("%s",message?message:"backend throws authentication error")));
 			}
-			if (message)
-				pfree(message);
 		}
         ereport(ERROR,
 			(errmsg("crypt authentication failed"),
@@ -783,7 +778,7 @@ static int do_crypt(POOL_CONNECTION *backend, POOL_CONNECTION *frontend, int rea
 	pool_read(backend, &kind, sizeof(kind));
 
 	/* if authenticated, save info */
-	if (kind == 0)
+	if (!reauth && kind == 0)
 	{
 		int msglen;
 
@@ -1046,15 +1041,13 @@ static int send_password_packet(POOL_CONNECTION *backend, int protoMajor, char *
 	{
 		if(response == 'E') /* Backend has thrown an error instead */
 		{
-			char* message = NULL;
+			char* message;
 			if (pool_extract_error_message(false, backend, protoMajor, false, &message) == 1)
 			{
 				ereport(ERROR,
 						(errmsg("authentication failed"),
 						 errdetail("%s",message?message:"backend throws authentication error")));
 			}
-			if (message)
-				pfree(message);
 		}
         ereport(ERROR,
 			(errmsg("authentication failed"),
@@ -1128,12 +1121,10 @@ int pool_read_message_length(POOL_CONNECTION_POOL *cp)
 				 errdetail("slot: %d length: %d", i, length)));
 
 		if (length != length0)
-		{
-			ereport(LOG,
-					(errmsg("unable to read message length"),
-					 errdetail("message length (%d) in slot %d does not match with slot 0(%d)", length, i, length0)));
-			return -1;
-		}
+            ereport(ERROR,
+                    (errmsg("unable to read message length"),
+                     errdetail("message length (%d) in slot %d does not match with slot 0(%d)", length, i, length0)));
+            
 	}
 
 	if (length0 < 0)
