@@ -233,19 +233,10 @@ void pool_set_query_in_progress(void)
  */
 void pool_unset_query_in_progress(void)
 {
-	POOL_SESSION_CONTEXT *s = pool_get_session_context(false);
-
 	ereport(DEBUG1,
 		(errmsg("session context: unsetting query in progress. DONE")));
 
-	s->in_progress = false;
-
-	/* Restore where_to_send map if neccessary */
-	if (s->need_to_restore_where_to_send)
-	{
-		memcpy(s->query_context->where_to_send,s->where_to_send_save, sizeof(s->where_to_send_save));
-	}
-	s->need_to_restore_where_to_send = false;
+	pool_get_session_context(false)->in_progress = false;
 }
 
 /*
@@ -347,9 +338,6 @@ bool pool_remove_sent_message(char kind, const char *name)
 	int i;
 	POOL_SENT_MESSAGE_LIST *msglist;
 
-	if (kind == 0 || name == NULL)
-		return false;
-
 	msglist = &pool_get_session_context(false)->message_list;
 
 	for (i = 0; i < msglist->size; i++)
@@ -460,30 +448,6 @@ void pool_clear_sent_message_list(void)
 	}
 }
 
-/*
- * Zap query context info in sent messages to indicate that the query context
- * has been already removed.
- */
-void
-pool_zap_query_context_in_sent_messages(POOL_QUERY_CONTEXT *query_context)
-{
-	int			i;
-	POOL_SENT_MESSAGE_LIST *msglist;
-
-	msglist = &pool_get_session_context(false)->message_list;
-
-	for (i = 0; i < msglist->size; i++)
-	{
-		elog(LOG, "checking zapping sent message: %p query_context: %p",
-			 &msglist->sent_messages[i], msglist->sent_messages[i]->query_context);
-		if (msglist->sent_messages[i]->query_context == query_context)
-		{
-			msglist->sent_messages[i]->query_context = NULL;
-			elog(LOG, "Zap sent message: %p", &msglist->sent_messages[i]);
-		}
-	}
-}
-
 static void dump_sent_message(char *caller, POOL_SENT_MESSAGE *m)
 {
 	ereport(DEBUG1,
@@ -593,7 +557,7 @@ void pool_add_sent_message(POOL_SENT_MESSAGE *message)
 }
 
 /*
- * Find a sent message by kind and name.
+ * Get a sent message
  */
 POOL_SENT_MESSAGE *pool_get_sent_message(char kind, const char *name, POOL_SENT_MESSAGE_STATE state)
 {
@@ -602,9 +566,6 @@ POOL_SENT_MESSAGE *pool_get_sent_message(char kind, const char *name, POOL_SENT_
 
 	msglist = &pool_get_session_context(false)->message_list;
 
-	if (kind == 0 || name == NULL)
-		return NULL;
-
 	for (i = 0; i < msglist->size; i++)
 	{
 		if (msglist->sent_messages[i]->kind == kind &&
@@ -616,29 +577,6 @@ POOL_SENT_MESSAGE *pool_get_sent_message(char kind, const char *name, POOL_SENT_
 	return NULL;
 }
 
-/*
- * Find a sent message by query context.
- */
-POOL_SENT_MESSAGE *
-pool_get_sent_message_by_query_context(POOL_QUERY_CONTEXT * query_context)
-{
-	int			i;
-	POOL_SENT_MESSAGE_LIST *msglist;
-
-	msglist = &pool_get_session_context(false)->message_list;
-
-	if (query_context == NULL)
-		return NULL;
-
-	for (i = 0; i < msglist->size; i++)
-	{
-		if (msglist->sent_messages[i]->query_context == query_context)
-			return msglist->sent_messages[i];
-	}
-
-	return NULL;
-}
-
 /*
  * Set message state to POOL_SENT_MESSAGE_STATE to POOL_SENT_MESSAGE_CLOSED.
  */
@@ -1133,13 +1071,6 @@ void pool_pending_message_query_context_dest_set(POOL_PENDING_MESSAGE* message,
 {
 	int i;
 
-	POOL_SESSION_CONTEXT *s = pool_get_session_context(false);
-
-	/* Save where_to_send map */
-	memcpy(s->where_to_send_save, query_context->where_to_send, sizeof(s->where_to_send_save));
-	s->need_to_restore_where_to_send = true;
-
-	/* Rewrite where_to_send map */
 	memset(query_context->where_to_send, 0, sizeof(query_context->where_to_send));
 
 	for (i=0;i<2;i++)
@@ -1207,9 +1138,8 @@ void pool_pending_message_add(POOL_PENDING_MESSAGE* message)
 
 	if (message->type != POOL_SYNC)
 		ereport(Elevel,
-				(errmsg("pool_pending_message_add: message type:%s message len:%d query:%s statement:%s portal:%s node_ids[0]:%d node_ids[1]:%d",
-						pool_pending_message_type_to_string(message->type),
-						message->contents_len, message->query, message->statement, message->portal,
+				(errmsg("pool_pending_message_add: message type:%d message len:%d query:%s statement:%s portal:%s node_ids[0]:%d node_ids[1]:%d",
+						message->type, message->contents_len, message->query, message->statement, message->portal,
 						message->node_ids[0], message->node_ids[1])));
 	else
 		ereport(Elevel,
@@ -1247,9 +1177,8 @@ POOL_PENDING_MESSAGE *pool_pending_message_head_message(void)
 	m = (POOL_PENDING_MESSAGE *) lfirst(cell);
 	message = copy_pending_message(m);
 	ereport(Elevel,
-			(errmsg("pool_pending_message_head_message: message type:%s message len:%d query:%s statement:%s portal:%s node_ids[0]:%d node_ids[1]:%d",
-					pool_pending_message_type_to_string(message->type),
-					message->contents_len, message->query, message->statement, message->portal,
+			(errmsg("pool_pending_message_head_message: message type:%d message len:%d query:%s statement:%s portal:%s node_ids[0]:%d node_ids[1]:%d",
+					message->type, message->contents_len, message->query, message->statement, message->portal,
 					message->node_ids[0], message->node_ids[1])));
 
 	MemoryContextSwitchTo(old_context);
@@ -1284,9 +1213,8 @@ POOL_PENDING_MESSAGE *pool_pending_message_pull_out(void)
 	m = (POOL_PENDING_MESSAGE *) lfirst(cell);
 	message = copy_pending_message(m);
 	ereport(Elevel,
-			(errmsg("pool_pending_message_pull_out: message type:%s message len:%d query:%s statement:%s portal:%s node_ids[0]:%d node_ids[1]:%d",
-					pool_pending_message_type_to_string(message->type),
-					message->contents_len, message->query, message->statement, message->portal,
+			(errmsg("pool_pending_message_pull_out: message type:%d message len:%d query:%s statement:%s portal:%s node_ids[0]:%d node_ids[1]:%d",
+					message->type, message->contents_len, message->query, message->statement, message->portal,
 					message->node_ids[0], message->node_ids[1])));
 
 	pool_pending_message_free_pending_message(m);
@@ -1393,7 +1321,7 @@ void pool_pending_message_reset_previous_message(void)
 				(errmsg("pool_pending_message_reset_previous_message: session context is not initialized")));
 		return;
 	}
-	session_context->previous_message_exists = false;
+	session_context->previous_message = NULL;
 }
 
 /*
@@ -1407,13 +1335,11 @@ void pool_pending_message_set_previous_message(POOL_PENDING_MESSAGE *message)
 				(errmsg("pool_pending_message_set_previous_message: session context is not initialized")));
 		return;
 	}
-	session_context->previous_message_exists = true;
-	memcpy(&session_context->previous_message, message, sizeof(POOL_PENDING_MESSAGE));
+	session_context->previous_message = message;
 }
 
 /*
- * Get previous message. This actually returns the address of memory. Do not
- * try to free using pool_pending_message_free_pending_message().
+ * Get previous message.
  */
 POOL_PENDING_MESSAGE *pool_pending_message_get_previous_message(void)
 {
@@ -1423,10 +1349,7 @@ POOL_PENDING_MESSAGE *pool_pending_message_get_previous_message(void)
 				(errmsg("pool_pending_message_get_previous_message: session context is not initialized")));
 		return NULL;
 	}
-	if (session_context->previous_message_exists == false)
-		return NULL;
-
-	return &session_context->previous_message;
+	return session_context->previous_message;
 }
 
 /*
@@ -1437,119 +1360,6 @@ bool pool_pending_message_exists(void)
 	return list_length(session_context->pending_messages) > 0;
 }
 
-/*
- * Convert enum pending message type to string. The returned string must not
- * be modified or freed.
- */
-const char *pool_pending_message_type_to_string(POOL_MESSAGE_TYPE type)
-{
-	static const char *pending_msg_string[] = {"Parse", "Bind", "Execute",
-											   "Descripbe", "Close", "Sync"};
-	if (type < 0 || type > POOL_SYNC)
-		return "unknown type";
-	return pending_msg_string[type];
-}
-
-/*
- * Find the latest pending message having specified query context.  The
- * returned message is a pointer to the message list. So do not free it using
- * pool_pending_message_free_pending_message.
- */
-POOL_PENDING_MESSAGE *pool_pending_message_find_lastest_by_query_context(POOL_QUERY_CONTEXT *qc)
-{
-	List *msgs;
-	POOL_PENDING_MESSAGE *msg;
-	int len;
-	ListCell *cell;
-
-	if (!session_context)
-	{
-		ereport(ERROR,
-				(errmsg("pool_pending_message_find_lastest_by_query_context: session context is not initialized")));
-	}
-
-	if (!session_context->pending_messages)
-		return NULL;
-
-	msgs = session_context->pending_messages;
-
-	len = list_length(msgs);
-	if (len <= 0)
-		return NULL;
-
-	ereport(DEBUG1,
-			(errmsg("pool_pending_message_find_lastest_by_query_context: num messages: %d",
-					len)));
-
-	while (len--)
-	{
-		cell = list_nth_cell(msgs, len);
-		if (cell)
-		{
-			msg = (POOL_PENDING_MESSAGE *) lfirst(cell);
-			if (msg->query_context == qc)
-			{
-				ereport(DEBUG1,
-						(errmsg("pool_pending_message_find_lastest_by_query_context: msg found. type: %s",
-								pool_pending_message_type_to_string(msg->type))));
-				return msg;
-			}
-			ereport(DEBUG1,
-					(errmsg("pool_pending_message_find_lastest_by_query_context: type: %s",
-							pool_pending_message_type_to_string(msg->type))));
-		}
-	}
-	return NULL;
-}
-
-/*
- * Get target backend id from pending message assuming that the destination for
- * the pending message is one of primary or standby node.
- */
-int pool_pending_message_get_target_backend_id(POOL_PENDING_MESSAGE *msg)
-{
-	int backend_id = -1;
-
-	if (msg->node_ids[0] != -1)
-		backend_id = msg->node_ids[0];
-	else if (msg->node_ids[1] != -1)
-		backend_id = msg->node_ids[1];
-	else
-		ereport(ERROR,
-				(errmsg("pool_pending_message_get_target_backend_id: no target backend id found")));
-
-	return backend_id;
-}
-
-/*
- * Get number of pending message list entries of which target backend is same as specified one.
- */
-int
-pool_pending_message_get_message_num_by_backend_id(int backend_id)
-{
-	ListCell   *cell;
-	ListCell   *next;
-	int        cnt = 0;
-
-	if (!session_context)
-	{
-		ereport(ERROR,
-				(errmsg("pool_pending_message_get_message_num_by_backend_id: session context is not initialized")));
-		return 0;
-	}
-
-	for (cell = list_head(session_context->pending_messages); cell; cell = next)
-	{
-		POOL_PENDING_MESSAGE *msg = (POOL_PENDING_MESSAGE *) lfirst(cell);
-
-		if (msg->node_ids[0] == backend_id || msg->node_ids[1] == backend_id) 
-			cnt++;
-
-		next = lnext(cell);
-	}
-	return cnt;
-}
-
 /*
  * Dump whole pending message list
  */
