@@ -4,7 +4,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2019	PgPool Global Development Group
+ * Copyright (c) 2003-2016	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -52,7 +52,7 @@
 
 #define MAX_FILE_LINE_LEN    512
 
-extern char *pcp_conf_file; /* global variable defined in main.c holds the path for pcp.conf */
+extern char pcp_conf_file[POOLMAXPATHLEN+1]; /* global variable defined in main.c holds the path for pcp.conf */
 volatile sig_atomic_t pcp_worker_wakeup_request = 0;
 PCP_CONNECTION* volatile pcp_frontend = NULL;
 
@@ -207,7 +207,6 @@ pcp_worker_main(int port)
 
 		/* process a request */
 		pcp_process_command(tos, buf, rsize);
-		pfree(buf);
 	}
 	exit(0);
 }
@@ -218,7 +217,8 @@ static void
 pcp_process_command(char tos, char *buf, int buf_len)
 {
 
-	if (tos == 'O' || tos == 'T')
+	if (tos == 'C' || tos == 'd' || tos == 'D' || tos == 'j' ||
+		tos == 'J' || tos == 'O' || tos == 'T')
 	{
 		if (Req_info->switching)
 		{
@@ -502,14 +502,14 @@ static int pool_detach_node(int node_id, bool gracefully)
 {
 	if (!gracefully)
 	{
-		degenerate_backend_set_ex(&node_id, 1, true, false, 0);
+		degenerate_backend_set_ex(&node_id, 1, true, false, true, 0);
 		return 0;
 	}
 
 	/* Check if the NODE DOWN can be executed on
 	 * the given node id.
 	 */
-	degenerate_backend_set_ex(&node_id, 1, true, true, 0);
+	degenerate_backend_set_ex(&node_id, 1, true, true, true, 0);
 
 	/*
 	 * Wait until all frontends exit
@@ -529,7 +529,7 @@ static int pool_detach_node(int node_id, bool gracefully)
 	/*
 	 * Now all frontends have gone. Let's do failover.
 	 */
-	degenerate_backend_set_ex(&node_id, 1, true, false, 0);
+	degenerate_backend_set_ex(&node_id, 1, true, false, true, 0);
 
 	/*
 	 * Wait for failover completed.
@@ -934,12 +934,12 @@ process_recovery_request(PCP_CONNECTION *frontend,char *buf)
 
 	if ((!REPLICATION &&
 		 !(MASTER_SLAVE &&
-		   !strcmp(pool_config->master_slave_sub_mode, MODE_STREAMREP))) ||
+		   pool_config->master_slave_sub_mode == STREAM_MODE)) ||
 		(MASTER_SLAVE &&
-		 !strcmp(pool_config->master_slave_sub_mode, MODE_STREAMREP) &&
+		 pool_config->master_slave_sub_mode == STREAM_MODE &&
 		 node_id == PRIMARY_NODE_ID))
 	{
-		if (MASTER_SLAVE && !strcmp(pool_config->master_slave_sub_mode, MODE_STREAMREP))
+		if (MASTER_SLAVE && pool_config->master_slave_sub_mode == STREAM_MODE)
 			ereport(ERROR,
 				(errmsg("process recovery request failed"),
 					 errdetail("primary server cannot be recovered by online recovery.")));
@@ -1051,7 +1051,7 @@ process_promote_node(PCP_CONNECTION *frontend, char *buf, char tos)
 				(errmsg("could not process recovery request"),
 				 errdetail("node id %d is not valid", node_id)));
 	/* promoting node is reserved to Streaming Replication */
-	if (!MASTER_SLAVE || (strcmp(pool_config->master_slave_sub_mode, MODE_STREAMREP) != 0))
+	if (!MASTER_SLAVE || pool_config->master_slave_sub_mode != STREAM_MODE)
 	{
 		ereport(FATAL,
 			(errmsg("invalid pgpool mode for process recovery request"),
