@@ -40,7 +40,7 @@
 #include "utils/pool_stream.h"
 
 static int extract_ntuples(char *message);
-static POOL_STATUS handle_mismatch_tuples(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend, char *packet, int packetlen, bool command_complete);
+static POOL_STATUS handle_mismatch_tuples(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend, char *packet, int packetlen);
 static int foward_command_complete(POOL_CONNECTION *frontend, char *packet, int packetlen);
 static int foward_empty_query(POOL_CONNECTION *frontend, char *packet, int packetlen);
 static int foward_packet_to_frontend(POOL_CONNECTION *frontend, char kind, char *packet, int packetlen);
@@ -62,7 +62,7 @@ POOL_STATUS CommandComplete(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *bac
 	/*
 	 * Handle misc process which is neccessary when query context exists.
 	 */
-	if (session_context->query_context != NULL && (!STREAM || (SL_MODE && !pool_is_doing_extended_query_message())))
+	if (session_context->query_context != NULL && !STREAM)
 		handle_query_context(backend);
 
 	/*
@@ -72,8 +72,6 @@ POOL_STATUS CommandComplete(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *bac
 	 */
 	if (STREAM && pool_is_doing_extended_query_message())
 	{
-		p1 = NULL;
-
 		for (i=0;i<NUM_BACKENDS;i++)
 		{
 			if (VALID_BACKEND(i))
@@ -81,11 +79,7 @@ POOL_STATUS CommandComplete(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *bac
 				con = CONNECTION(backend, i);
 
 				if (pool_read(con, &len, sizeof(len)) < 0)
-				{
-					if (p1 != NULL)
-						pfree(p1);
 					return POOL_END;
-				}
 
 				len = ntohl(len);
 				len -= 4;
@@ -93,13 +87,7 @@ POOL_STATUS CommandComplete(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *bac
 
 				p = pool_read2(con, len);
 				if (p == NULL)
-				{
-					if (p1 != NULL)
-						pfree(p1);
 					return POOL_END;
-				}
-				if (p1 != NULL)
-					pfree(p1);
 				p1 = palloc(len);
 				memcpy(p1, p, len);
 
@@ -107,11 +95,10 @@ POOL_STATUS CommandComplete(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *bac
 					session_context->query_context->parse_tree &&
 					is_start_transaction_query(session_context->query_context->parse_tree))
 					TSTATE(backend, i) ='T';		/* we are inside a transaction */
-				{
+
 					ereport(DEBUG1,
 							(errmsg("processing command complete"),
 							 errdetail("set transaction state to T")));
-				}
 			}
 		}
 	}
@@ -156,7 +143,7 @@ POOL_STATUS CommandComplete(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *bac
 	}
 	else
 	{
-		if (handle_mismatch_tuples(frontend, backend, p1, len1, command_complete) != POOL_CONTINUE)
+		if (handle_mismatch_tuples(frontend, backend, p1, len1) != POOL_CONTINUE)
 			return POOL_END;
 	}
 
@@ -167,22 +154,6 @@ POOL_STATUS CommandComplete(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *bac
 		{
 			memqcache_register('C', frontend, p1, len1);
 		}
-
-		/*
-		 * If we are in streaming replication mode and we are doing extended
-		 * query, register query cache now.
-		 */
-		if (STREAM && pool_is_doing_extended_query_message())
-		{
-			char *query;
-			Node *node;
-			char state;
-
-			query = session_context->query_context->query_w_hex;
-			node = pool_get_parse_tree();
-			state = TSTATE(backend, MASTER_NODE_ID);
-			pool_handle_query_cache(backend, query, node, state);
-		}
 	}
 
 	pfree(p1);
@@ -198,34 +169,8 @@ POOL_STATUS CommandComplete(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *bac
 	*/
 	if (STREAM && pool_is_doing_extended_query_message())
 	{
-		pool_at_command_success(frontend, backend);
 		pool_unset_query_in_progress();
 		pool_pending_message_reset_previous_message();
-
-		if (session_context->query_context == NULL)
-		{
-			elog(WARNING, "At command complete there's no query context");
-		}
-		else
-		{
-			/*
-			 * Destroy query context if it is not referenced from sent
-			 * messages and pending messages except bound to named statements
-			 * or portals.  Named statements and portals should remain until
-			 * they are explicitly closed.
-			 */
-			if (can_query_context_destroy(session_context->query_context))
-
-			{
-				POOL_SENT_MESSAGE * msg = pool_get_sent_message_by_query_context(session_context->query_context);
-
-				if (!msg || (msg && *msg->name == '\0'))
-				{
-					pool_zap_query_context_in_sent_messages(session_context->query_context);
-					pool_query_context_destroy(session_context->query_context);
-				}
-			}
-		}
 	}
 
 	return POOL_CONTINUE;
@@ -337,7 +282,7 @@ static int extract_ntuples(char *message)
 /*
  * Handle mismatch tuples
  */
-static POOL_STATUS handle_mismatch_tuples(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend, char *packet, int packetlen, bool command_complete)
+static POOL_STATUS handle_mismatch_tuples(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend, char *packet, int packetlen)
 {
 	POOL_SESSION_CONTEXT *session_context;
 
@@ -431,16 +376,8 @@ static POOL_STATUS handle_mismatch_tuples(POOL_CONNECTION *frontend, POOL_CONNEC
 	}
 	else
 	{
-		if (command_complete)
-		{
-			if (foward_command_complete(frontend, packet, packetlen) < 0)
-				return POOL_END;
-		}
-		else
-		{
-			if (foward_empty_query(frontend, packet, packetlen) < 0)
-				return POOL_END;
-		}
+		if (foward_command_complete(frontend, packet, packetlen) < 0)
+			return POOL_END;
 	}
 
 	return POOL_CONTINUE;
@@ -467,11 +404,11 @@ static int foward_empty_query(POOL_CONNECTION *frontend, char *packet, int packe
  */
 static int foward_packet_to_frontend(POOL_CONNECTION *frontend, char kind, char *packet, int packetlen)
 {
- 	int sendlen;
+	int sendlen;
 
 	if (pool_write(frontend, &kind, 1) < 0)
- 		return -1;
- 
+		return -1;
+
 	sendlen = htonl(packetlen+4);
 	if (pool_write(frontend, &sendlen, sizeof(sendlen)) < 0)
 		return -1;
